##  Step 3: Test the Identity Provider Configuration
  1. In SAP LeanIX, navigate to **Administration** > **Authentication and SSO**.
  2. On the IdP tile, select **Test Configuration**.
  3. Follow the test instructions. Open the provided URL in an incognito browser and login with the credentials for your IdP.
If the test worked, you’re logged in to the workspace.
